﻿# Filename:      	maintenancemode_scvmm.ps1
#Copyright(c) 2012,by Eaton Corporation.All rights reserved
# Description:   	Powershell script to log windows event for UPS power failure and power restore.
# Usage: 			maintenancemode_scvmm {VMMServerIP} {HostIp} {waittime} {Enter[1] /Exit [0] Maintaince Mode}
# Example:			
# 					Log windows event for entering host 'host' managed by scvmm server 'scvmm' into maintenance mode.
#   						maintenancemode_scvmm scvmm host time 1
# 					Log windows event for exiting host 'host' managed by scvmm server 'scvmm' from maintenance mode.
#   						maintenancemode_scvmm scvmm host time 0

param ($VMMServerName,$VMHost,$IsStartMaintenance ,$waittime )
#waittime in minutes
if ($VMHost -eq $null -or $VMMServerName -eq $null  -or $IsStartMaintenance -eq $null)
{
  	Write-Host -foregroundcolor DarkGray "`nUsage: maintenancemode_scvmm -VMHost <Host machine in SCVMM>-VMMServerName <SCVMM server> -IsStartMaintenance < 1 for Start Maintence 0 for End Maintenance>"
  	
}
else
{

	 #Add Snap-In
	if ( (Get-PSSnapin -Name Microsoft.SystemCenter.VirtualMachineManager -ErrorAction SilentlyContinue) -eq $null )
	{
	    Add-PSSnapin Microsoft.SystemCenter.VirtualMachineManager
	}
	 
     	 #If UPS power failure occurs
   	if($IsStartMaintenance -eq 1)
    	{
		$inifile = ".\" + $VMHost + ".ini"       
		$var = Get-Content $inifile	#Read ini file of the VMhost.
		
		Remove-Item .\time_powerrestore.ini
		if ($var -eq 1 )	
		{
			
			$powerfailtime_stored = get-Content ".\time_powerfailure.ini"	

			$powerfaildatetime = Get-Date
			$TotalTimeDifference = New-TimeSpan -Start $powerfailtime_stored -End $powerfaildatetime
			$diff_minutes= ($TotalTimeDifference).TotalMinutes

			if ($diff_minutes -ge $waittime)

			{
				Get-VMMServer -ComputerName $VMMServerName
				$host1 = Get-VMHost -ComputerName $VMHost
				$maintenance_value = $host1.MaintenanceHost
				Write-Output $maintenance_value
				if ($host1.MaintenanceHost -eq "True")
				{	
					exit;
				}
				else #PRO Tip Implemented 
				{

					$msg="AC power failure to Eaton UPS which is monitoring the host " + $VMHost
	        			$EventLog = New-Object System.Diagnostics.EventLog('Application')
					$EventLog.Source = "IPM"				
					$EventLog.WriteEntry([string]::join(":",($VMHost,$msg)),"Error" , 120) 
					Remove-Item .\time_powerfailure.ini								
					#Event to generate critical power failure alert
					exit;
				}
				
			}
			else
			{

				Exit;
				#nothing
			}
			
		}

		Set-Content $inifile 1 	
     		$msg="AC power failure to Eaton UPS which is monitoring the host " + $VMHost
       		$EventLog = New-Object System.Diagnostics.EventLog('Application')
		$EventLog.Source = "IPM"
		$EventLog.WriteEntry([string]::join(":",($VMHost,$msg)),"warning" , 116) #Event to generate power failure alert

       		#write JSON file
        	$filename =  ".\" + $VMHost + ".json"
       		$file  = New-Item -type file $filename -Force
        	Add-Content $file "var VMHostMaintenanceTag = {"
        	Add-Content $file ('"Host":')
        	Add-Content $file "{"      
	  	Add-Content $file ('"vmTag":1')
       		Add-Content $file "}"
        	Add-Content $file "}"
		$current_date = Get-Date
		$ini_powerfailure = ".\time_powerfailure.ini"
		Set-Content $ini_powerfailure $current_date
		

			
	}


    #If UPS power restore occurs
    if($IsStartMaintenance -eq 0)
    { 
	
		$inifile = ".\" + $VMHost + ".ini"
		$var = Get-Content $inifile
		Remove-Item .\time_powerfailure.ini
		if ($var -eq 1)
		{
			set-Content $inifile 0 
			$msg="AC power restore to Eaton UPS which is monitoring the host " + $VMHost
			$EventLog = New-Object System.Diagnostics.EventLog('Application')
			$EventLog.Source = "IPM"
			$EventLog.WriteEntry([string]::join(":",($VMHost,$msg)),"Warning", 119) #Event to generate power restore alert
        
        
        		#write JSON file 	
	       	 	$filename =  ".\" + $VMHost + ".json"
	        	$file  = New-Item -type file $filename -Force
	        	Add-Content $file "var VMHostMaintenanceTag = {"
		        Add-Content $file ('"Host":')
		        Add-Content $file "{"
		        Add-Content $file ('"vmTag":0')
	        	Add-Content $file "}"
		        Add-Content $file "}"
			$current_date = Get-Date
			$ini_powerrestore = ".\time_powerrestore.ini"
			Set-Content $ini_powerrestore $current_date
			
		}
		else
		{
			

			$powerrestoretime_stored = get-Content ".\time_powerrestore.ini"	
			$powerrestoredatetime = Get-Date
			$TotalTimeDifference = New-TimeSpan -Start $powerrestoretime_stored -End $powerrestoredatetime

			$diff_minutes= ($TotalTimeDifference).TotalMinutes

			if ($diff_minutes -ge $waittime)
			{

				Get-VMMServer -ComputerName $VMMServerName
				$host1 = Get-VMHost -ComputerName $VMHost
				$maintenance_value = $host1.MaintenanceHost

				if ($maintenance_value -eq "True")#Check if the host is in maintenance mode(PRO Tip not implemented)
				{
					$msg="AC power restore to Eaton UPS which is monitoring the host " + $VMHost
	        			$EventLog = New-Object System.Diagnostics.EventLog('Application')
					$EventLog.Source = "IPM"
					$EventLog.WriteEntry([string]::join(":",($VMHOst,$msg)),"Error" , 124) 
					Remove-Item .\time_powerrestore.ini
					#Event to generate critical power restore alert
					exit;
				}

				else #PRO Tip Implemented
				{
					exit;
				}

			}
			else

			{
				exit;

			}
		}
      
   } 
    
 }
 
# SIG # Begin signature block
# MIIZwQYJKoZIhvcNAQcCoIIZsjCCGa4CAQExCzAJBgUrDgMCGgUAMGkGCisGAQQB
# gjcCAQSgWzBZMDQGCisGAQQBgjcCAR4wJgIDAQAABBAfzDtgWUsITrck0sYpfvNR
# AgEAAgEAAgEAAgEAAgEAMCEwCQYFKw4DAhoFAAQUKSrdYzUUyLiqod2rxy7FkfpF
# iiegghSQMIIDdTCCAl2gAwIBAgILBAAAAAABFUtaw5QwDQYJKoZIhvcNAQEFBQAw
# VzELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExEDAOBgNV
# BAsTB1Jvb3QgQ0ExGzAZBgNVBAMTEkdsb2JhbFNpZ24gUm9vdCBDQTAeFw05ODA5
# MDExMjAwMDBaFw0yODAxMjgxMjAwMDBaMFcxCzAJBgNVBAYTAkJFMRkwFwYDVQQK
# ExBHbG9iYWxTaWduIG52LXNhMRAwDgYDVQQLEwdSb290IENBMRswGQYDVQQDExJH
# bG9iYWxTaWduIFJvb3QgQ0EwggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
# AQDaDuaZjc6j40+Kfvvxi4Mla+pIH/EqsLmVEQS98GPR4mdmzxzdzxtIK+6NiY6a
# rymAZavpxy0Sy6scTHAHoT0KMM0VjU/43dSMUBUc71DuxC73/OlS8pF94G3VNTCO
# XkNz8kHp1Wrjsok6Vjk4bwY8iGlbKk3Fp1S4bInMm/k8yuX9ifUSPJJ4ltbcdG6T
# RGHRjcdGsnUOhugZitVtbNV4FpWi6cgKOOvyJBNPc1STE4U6G7weNLWLBYy5d4ux
# 2x8gkasJU26Qzns3dLlwR5EiUWMWea6xrkEmCMgZK9FGqkjWZCrXgzT/LCrBbBlD
# SgeF59N89iFo7+ryUp9/k5DPAgMBAAGjQjBAMA4GA1UdDwEB/wQEAwIBBjAPBgNV
# HRMBAf8EBTADAQH/MB0GA1UdDgQWBBRge2YaRQ2XyolQL30EzTSo//z9SzANBgkq
# hkiG9w0BAQUFAAOCAQEA1nPnfE920I2/7LqivjTFKDK1fPxsnCwrvQmeU79rXqoR
# SLblCKOzyj1hTdNGCbM+w6DjY1Ub8rrvrTnhQ7k4o+YviiY776BQVvnGCv04zcQL
# cFGUl5gE38NflNUVyRRBnMRddWQVDf9VMOyGj/8N7yy5Y0b2qvzfvGn9LhJIZJrg
# lfCm7ymPAbEVtQwdpf5pLGkkeB6zpxxxYu7KyJesF12KwvhHhm4qxFYxldBniYUr
# +WymXUadDKqC5JlR3XC321Y9YeRq4VzW9v493kHMB65jUr9TU/Qr6cf9tveCX4XS
# QRjbgbMEHMUfpIBvFSDJ3gyICh3WZlXi/EjJKSZp4DCCBBowggMCoAMCAQICCwQA
# AAAAASAZwZBmMA0GCSqGSIb3DQEBBQUAMFcxCzAJBgNVBAYTAkJFMRkwFwYDVQQK
# ExBHbG9iYWxTaWduIG52LXNhMRAwDgYDVQQLEwdSb290IENBMRswGQYDVQQDExJH
# bG9iYWxTaWduIFJvb3QgQ0EwHhcNMDkwMzE4MTEwMDAwWhcNMjgwMTI4MTIwMDAw
# WjBUMRgwFgYDVQQLEw9UaW1lc3RhbXBpbmcgQ0ExEzARBgNVBAoTCkdsb2JhbFNp
# Z24xIzAhBgNVBAMTGkdsb2JhbFNpZ24gVGltZXN0YW1waW5nIENBMIIBIjANBgkq
# hkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAwwy3Eg1NaIoz3jYF8Dy69drNDlN7Rp+C
# 8mIT18F3rbuBN35PHpOBwQYi2h1QhMaXlZKpk7Y9q4Z5GVR9DhYETMSIlyzGoahf
# FTrSZCvMPgx66KRWsR67z4TOjTU6NJxsLcB3tTCpH2fmOglEOkNyQaKRw0aaH7a5
# pw+vHHUbZCXnCGwUR/VHGt6O6qJjlX31qK1VomSbcm+5AnM/OYo5XMT+j/sRnL0Q
# GUlj0EMii9arkpl0FM8wB75Pvf2Kj55a3208zFqZUJC5rcKXQ8Jf7c0zPYfMwaBb
# qWI7eH1ko6xNHyvXAxFscVSKsKuxHNZ9I9tABzcm21CvOD2mB3VvlwIDAQABo4Hp
# MIHmMA4GA1UdDwEB/wQEAwIBBjASBgNVHRMBAf8ECDAGAQH/AgEAMB0GA1UdDgQW
# BBTowvHEMtwzNTe8ZXb1nBcuF0Us/jBLBgNVHSAERDBCMEAGCSsGAQQBoDIBHjAz
# MDEGCCsGAQUFBwIBFiVodHRwOi8vd3d3Lmdsb2JhbHNpZ24ubmV0L3JlcG9zaXRv
# cnkvMDMGA1UdHwQsMCowKKAmoCSGImh0dHA6Ly9jcmwuZ2xvYmFsc2lnbi5uZXQv
# cm9vdC5jcmwwHwYDVR0jBBgwFoAUYHtmGkUNl8qJUC99BM00qP/8/UswDQYJKoZI
# hvcNAQEFBQADggEBAF32yysNAUCEn4V6Q3Bq4MXnqgYA12cTyQiRMWVPFKipBdw4
# nmqgMAq9jceAKO5CRcqU895YRamAMgT1WVxqcAA5J5RN9bRGNOgcUzGys1QW6cxC
# q9XZWTAc+0YnJbiHI7HodYgkgx7Idjd7AUlFSKTt4l3SfJyi3C26EFoSYmWrrgDH
# EDQ7y3K9FCQM3MN2J7Sn/uFYKfIOFp+ROR2JpuYPHIeM4liskn4kPqrsFOc6MzSL
# xjusg6sPFGJ6uhotTUsbxTDwC5J5fTx44Pjm0hWWWZk5KzBh6Lj4wKHpIhQReH3E
# 3Im+wLuU4XKu67VAQE/vFx5YXtCoiZaskijpur8wggQoMIIDEKADAgECAgsEAAAA
# AAEvTuE1XDANBgkqhkiG9w0BAQUFADBXMQswCQYDVQQGEwJCRTEZMBcGA1UEChMQ
# R2xvYmFsU2lnbiBudi1zYTEQMA4GA1UECxMHUm9vdCBDQTEbMBkGA1UEAxMSR2xv
# YmFsU2lnbiBSb290IENBMB4XDTExMDQxMzEwMDAwMFoXDTE5MDQxMzEwMDAwMFow
# UTELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24gbnYtc2ExJzAlBgNV
# BAMTHkdsb2JhbFNpZ24gQ29kZVNpZ25pbmcgQ0EgLSBHMjCCASIwDQYJKoZIhvcN
# AQEBBQADggEPADCCAQoCggEBALJPFOcQvtcmcqs2l+9Tv0KEXljRiij8Q0ZvfihE
# UAt1XQDXPApEniBqpPdFSjdgo24/Evpt+rZGw2qjuAwnKAJXKNFQ92E5VbjD4SWG
# Ujy/BR3Xs5r4miQxSdWiqeLTkas+PHPv9inxyDXQMHt/TpKlBo+H4s71wWNmrBhp
# KsFeu1robpX/O4BinZnHxy9m1f1iGoJVWsb6QHeOyTA8G/DyNbhsWZz96dbKtEAe
# 9wTK0WepdOOlCFTZgzU7jowjDHW23oZKnho+ClBJOJzSqJC/mPrIjCsnEX4q+87e
# qa44kyL6puz7XGF2w0TWzAx+L20GgKJ0QLu3H/Q713NUH/MCAwEAAaOB+jCB9zAO
# BgNVHQ8BAf8EBAMCAQYwEgYDVR0TAQH/BAgwBgEB/wIBADAdBgNVHQ4EFgQUCG7Y
# tpyKv+0+18N0XcyAH6gvUHowRwYDVR0gBEAwPjA8BgRVHSAAMDQwMgYIKwYBBQUH
# AgEWJmh0dHBzOi8vd3d3Lmdsb2JhbHNpZ24uY29tL3JlcG9zaXRvcnkvMDMGA1Ud
# HwQsMCowKKAmoCSGImh0dHA6Ly9jcmwuZ2xvYmFsc2lnbi5uZXQvcm9vdC5jcmww
# EwYDVR0lBAwwCgYIKwYBBQUHAwMwHwYDVR0jBBgwFoAUYHtmGkUNl8qJUC99BM00
# qP/8/UswDQYJKoZIhvcNAQEFBQADggEBACJcxd099Atw2OP158WOCQG7sZY2XFoH
# rceoRElRJXquDaQZO5Kcz7lCJrs7bJfnx84RbWiR2o1t8VNNVDiMYfPIgnZpvoEy
# CzHDbMmeIApYL/BI/n5IB6rXQ1iUc1QEMal4DTuMsHDBPX7XvS8qw+L1jwyQ3Gul
# yL5oXl1t+HjSvkmVHhV4CJH7NMi+hK284MbdGNvzyvB7whQ8GLgDupU+IR4/YGl6
# f2oDno1K+fAoLDCEXuwmckKxbctkwxKM1oRLZ0F8sQMXeAnjrai2li2kfoADT4j3
# wWtaRhXNLBmL2HCc5S1JiGByqKQZUnBDXtrWRgOwaA4k70r2CyUk7yQwggQuMIID
# FqADAgECAgsBAAAAAAElsLTMATANBgkqhkiG9w0BAQUFADBUMRgwFgYDVQQLEw9U
# aW1lc3RhbXBpbmcgQ0ExEzARBgNVBAoTCkdsb2JhbFNpZ24xIzAhBgNVBAMTGkds
# b2JhbFNpZ24gVGltZXN0YW1waW5nIENBMB4XDTA5MTIyMTA5MzI1NloXDTIwMTIy
# MjA5MzI1NlowUjELMAkGA1UEBhMCQkUxFjAUBgNVBAoTDUdsb2JhbFNpZ24gTlYx
# KzApBgNVBAMTIkdsb2JhbFNpZ24gVGltZSBTdGFtcGluZyBBdXRob3JpdHkwggEi
# MA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQDNwj1ddyLQwn04MsMVgx9CajtT
# Zt1qNkQNac9ojYlFn34v7kI6M3w+ANOXatha1cNNkgpfBlD9v2zEA6KCYNjtUi4T
# dN6XxkUhe1X26rFkA/x0a7Jfx2xsQxSKJBA3SZWB0kgSpaJ2SVAhf8qFcwo8XbUu
# rZCqXk0yyxeT2X+WwMCJZVbZxbE/mBsn+knuHRvLBowwHDvFp3BbqKsYWv7I9o6/
# AV2PYZg0D1hR/98y6lRlHBQrbPwMkBln7ZvZ2mOb1loko3SOCCMAoZK1HgvRCKBm
# f5Ibo+2AZAJJj7aE79FVjl6pl1rFCAKIlFa/kusqLQY1krU3NjHsw/56O8KFAgMB
# AAGjggEBMIH+MB8GA1UdIwQYMBaAFOjC8cQy3DM1N7xldvWcFy4XRSz+MDwGA1Ud
# HwQ1MDMwMaAvoC2GK2h0dHA6Ly9jcmwuZ2xvYmFsc2lnbi5uZXQvVGltZXN0YW1w
# aW5nMS5jcmwwHQYDVR0OBBYEFKqqporvpGRz1pXieciP6s+lYCnKMAkGA1UdEwQC
# MAAwDgYDVR0PAQH/BAQDAgeAMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMIMEsGA1Ud
# IAREMEIwQAYJKwYBBAGgMgEeMDMwMQYIKwYBBQUHAgEWJWh0dHA6Ly93d3cuZ2xv
# YmFsc2lnbi5uZXQvcmVwb3NpdG9yeS8wDQYJKoZIhvcNAQEFBQADggEBALyJ7P7m
# NlWTXHnUEXqGgI8XtpOybZuRoVYYEcZV6vYI7a2bnvUrgci73WB7G0eZHm1APh2A
# whPVjgQFL9vnrlKeaIRyoeVKYDz4m9UvRtjDsreTU6ybbEMkJNHx/OlWLjQRWBhD
# 6u//NHRsoMBsf60DGWmIHpVgyru9DLt278cksIHGODHPNq0MOLiQIISbLo8ouZ/2
# ypQnzaw5YVfg45VanHaSMPXeppc9chwqYDKoM02GNTOKXPOk/fcGLOFrSzD1y9ND
# YvhBud59IMsFjI4s9l81/TONQollCDYso4n0WoWLsLl722zLofjSDhu7l3zRJ3m+
# nXw75qdWNNjJkakwggSXMIIDf6ADAgECAhIRIZQ/Koz8on/gEHDiOqz+QgEwDQYJ
# KoZIhvcNAQEFBQAwUTELMAkGA1UEBhMCQkUxGTAXBgNVBAoTEEdsb2JhbFNpZ24g
# bnYtc2ExJzAlBgNVBAMTHkdsb2JhbFNpZ24gQ29kZVNpZ25pbmcgQ0EgLSBHMjAe
# Fw0xMTExMDMxODI1MjZaFw0xNDExMDMxODI1MjZaMGQxCzAJBgNVBAYTAlVTMQsw
# CQYDVQQIEwJOQzEQMA4GA1UEBxMHUmFsZWlnaDETMBEGA1UEChMKRWF0b24gQ29y
# cDEMMAoGA1UECxMDRFBRMRMwEQYDVQQDEwpFYXRvbiBDb3JwMIIBIjANBgkqhkiG
# 9w0BAQEFAAOCAQ8AMIIBCgKCAQEAoWq9ddd1ZFhdbiugZ4PHSrHjpHM8MvCwvJOT
# TO0imMs+snh7UHNUOqgeuUGojtAQN3p2RAeVR8zyRIP3llbaaB45HJ37SQ8Q8xQq
# Gy87Pe1Twf/F2njZxwKLKo/7c/a8lkFyWIuBOkL56S/HzQPwpIFoA6EtBIYYIlqu
# RW61q11SZR6mhUXXKyl/K+VL2Gbx5wn5UmYXOHjYdSh0KuvheBR+h7hUf0RvuT4u
# y/KwOddG1JvKoxLTrmtaWcN9cEi3oAD9tWAcGCfME6tY3kT0QBwSDx6PM7IZU0Yh
# cdvQw9PwR8yr84hmRUyI8c2W7PZ3n0YG/oXh+GERchI4GyqetQIDAQABo4IBVDCC
# AVAwDgYDVR0PAQH/BAQDAgeAMEwGA1UdIARFMEMwQQYJKwYBBAGgMgEyMDQwMgYI
# KwYBBQUHAgEWJmh0dHBzOi8vd3d3Lmdsb2JhbHNpZ24uY29tL3JlcG9zaXRvcnkv
# MAkGA1UdEwQCMAAwEwYDVR0lBAwwCgYIKwYBBQUHAwMwPgYDVR0fBDcwNTAzoDGg
# L4YtaHR0cDovL2NybC5nbG9iYWxzaWduLmNvbS9ncy9nc2NvZGVzaWduZzIuY3Js
# MFAGCCsGAQUFBwEBBEQwQjBABggrBgEFBQcwAoY0aHR0cDovL3NlY3VyZS5nbG9i
# YWxzaWduLmNvbS9jYWNlcnQvZ3Njb2Rlc2lnbmcyLmNydDAdBgNVHQ4EFgQUm27o
# Th7FrRDr08fza0JU0JqJQycwHwYDVR0jBBgwFoAUCG7YtpyKv+0+18N0XcyAH6gv
# UHowDQYJKoZIhvcNAQEFBQADggEBAElnwSkxcvHWX1o+PIdKTPyt2xhIWgaA+aB5
# 8sCICNJV9Z/sALFomi5JcmWeXeA43/Df0ktwxoprC5kA6gWeIeZX+rFUaJD7omVU
# gKfYRV2MT+SzcKKuQJUX4h492PutOCM1yZBHkwlfhRfSWkVPaFgtfytsOaLwt492
# U1/JAwk5AHzFK/doebpBWpUpjctIKTBQ8H5tE5MDlkgv2JjZYLjE1KEv8TYEIeKY
# yNxjYBtwQ0H3XMss5MroTMvgnwXSh6jGQUAV74bNtSDftJrv+iXPadUOR9/PEP0P
# NBW3viXx8849PqTWDDFvr0cAZFF5qvTj4GDpLsYHjsYZYIYjPmcxggSbMIIElwIB
# ATBnMFExCzAJBgNVBAYTAkJFMRkwFwYDVQQKExBHbG9iYWxTaWduIG52LXNhMScw
# JQYDVQQDEx5HbG9iYWxTaWduIENvZGVTaWduaW5nIENBIC0gRzICEhEhlD8qjPyi
# f+AQcOI6rP5CATAJBgUrDgMCGgUAoHAwEAYKKwYBBAGCNwIBDDECMAAwGQYJKoZI
# hvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcC
# ARUwIwYJKoZIhvcNAQkEMRYEFLHfJiukSWo1LqG3mlq0Nvv454PkMA0GCSqGSIb3
# DQEBAQUABIIBACCsctYS0zM90ka3h/I4YVYvkG7/LkYH/qxKxwhBG2R+cuJBajFW
# c/AN2g4CNku6Dgvn52o3BddYU6XHxt/socvLOvtdRsCIaniyAkg98jmkosFTFM8M
# Gen22rqP1JwEDL6c32UHems2ABbmdcL5MEah4fndDGNE5IsVvLEzCSNaeDqwQ2Qc
# 0HWCA7PcxO6ZbDizJSt3kQYXnQrCidW9WDkaMEHVS5CFMolp+SD6JEu9p2Oizmvp
# EDjAHNn1v5vUx+qW4A4/7k2nEI7ryIjTYj5Fl4+TY7nSSQLsdVmFMsEmKuqFXO18
# WSgVIuFnfpBJuCvxFyw0O+lNVVYbK7wO54mhggKXMIICkwYJKoZIhvcNAQkGMYIC
# hDCCAoACAQEwYzBUMRgwFgYDVQQLEw9UaW1lc3RhbXBpbmcgQ0ExEzARBgNVBAoT
# Ckdsb2JhbFNpZ24xIzAhBgNVBAMTGkdsb2JhbFNpZ24gVGltZXN0YW1waW5nIENB
# AgsBAAAAAAElsLTMATAJBgUrDgMCGgUAoIH3MBgGCSqGSIb3DQEJAzELBgkqhkiG
# 9w0BBwEwHAYJKoZIhvcNAQkFMQ8XDTEyMDEwNDEwMzY1MVowIwYJKoZIhvcNAQkE
# MRYEFKPiUE3VndK4h7VHhaIuBT4FXILGMIGXBgsqhkiG9w0BCRACDDGBhzCBhDCB
# gTB/BBSu3333a7okENZ9uvGPW6FbQX5JbDBnMFikVjBUMRgwFgYDVQQLEw9UaW1l
# c3RhbXBpbmcgQ0ExEzARBgNVBAoTCkdsb2JhbFNpZ24xIzAhBgNVBAMTGkdsb2Jh
# bFNpZ24gVGltZXN0YW1waW5nIENBAgsBAAAAAAElsLTMATANBgkqhkiG9w0BAQEF
# AASCAQC6G/5NurCFj26XL6S6GV+20NmpXqbeK0PJJOUKVLtn3MyJfVe+hwxXJvHg
# pXHaJaqnjrpz9ARZpxu5129fCOSzpvmNibHoASliH8tRdi4ddqs0/WmYp5U6OUJi
# vpvXL+UcBaEDtLNnY1z98TK85dGammq4MU1j+dC7roNssO6f/dL6AXzuOHT1/ATb
# V/mmYLoba3mjicTwfCFVHnfqv9EHDKkaBtaMbOjopORzP18uCKmlwWdVviR9CfBr
# PwOolDK8Zy/huCRXR/fAOkFPi/hDUuhyksGbMuWSgmeoh0hfsPG4zLIjcxtX3qwJ
# sHSOe6P9ZGW6KZ+WiCc1daO/zZqp
# SIG # End signature block
